# Developer Guide

## Dev setup

1. Install conda (we suggest `mambaforge`).
2. Setup the `fswp` python environment - just execute this:
   ```shell
   conda env create
   ```

### Dev Editor: suggestions

You can use any editor you want to collaborate on this project. Most of us use VSCode. When you open this repo in your editor, you should see a prompt suggesting our recommended VSCode extensions (e.g. Python, ruff for linting and gh-actions for CI/CD files).
